@@ -19,6 +19,7 @@
 #include <bakery/App/GtkDialogs.h>
 #include <bakery/App/Dialog_OfferSave.h>
 #include <bakery/App/Dialog_OverwriteFile.h>
+#include <bakery/App/App_Gtk.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/filechooserdialog.h>
@@ -30,7 +31,7 @@ namespace Bakery
 
 void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ustring& secondary_text)
 {
-  Gtk::MessageDialog dialog("<b>" + text + "</b>", true /* use markup */, Gtk::MESSAGE_WARNING);
+  Gtk::MessageDialog dialog(App_Gtk::util_bold_message(text), true /* use markup */, Gtk::MESSAGE_WARNING);
   dialog.set_secondary_text(secondary_text);
 
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
@@ -42,7 +43,7 @@ void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ust
   dialog.run();
 }
 
-Glib::ustring GtkDialogs::ui_file_select_open(App& app)
+Glib::ustring GtkDialogs::ui_file_select_open(App& app, const Glib::ustring& starting_folder_uri)
 {
   Gtk::FileChooserDialog fileChooser_Open(gettext("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
 
@@ -55,6 +56,9 @@ Glib::ustring GtkDialogs::ui_file_select_open(App& app)
 
   fileChooser_Open.set_default_response(Gtk::RESPONSE_OK);
 
+  if(!starting_folder_uri.empty())
+    fileChooser_Open.set_current_folder_uri(starting_folder_uri);
+
   int response_id = fileChooser_Open.run();
   fileChooser_Open.hide();
   if(response_id != Gtk::RESPONSE_CANCEL)
@@ -65,9 +69,10 @@ Glib::ustring GtkDialogs::ui_file_select_open(App& app)
     return "";
 }
 
-Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old_filepath)
+Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old_file_uri)
 {
   Gtk::FileChooserDialog fileChooser_Save(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+  fileChooser_Save.set_do_overwrite_confirmation(); //Ask the user if the file already exists.
 
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
   if(pWindow)
@@ -77,10 +82,10 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
   fileChooser_Save.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_OK);
 
   fileChooser_Save.set_default_response(Gtk::RESPONSE_OK);
-   
+
   //Make the save dialog show the existing filename, if any:
-  if(!old_filepath.empty())
-    fileChooser_Save.set_filename(old_filepath);
+  if(!old_file_uri.empty())
+    fileChooser_Save.set_uri(old_file_uri);
 
   int response_id = fileChooser_Save.run();
   fileChooser_Save.hide();
@@ -116,20 +121,4 @@ App_WithDoc::enumSaveChanges GtkDialogs::ui_offer_to_save_changes(App& app, cons
   return result;
 }
 
-bool GtkDialogs::ui_ask_overwrite(App& app, const std::string& filepath)
-{
-   Bakery::Dialog_OverwriteFile* pDialogQuestion = new Bakery::Dialog_OverwriteFile(filepath);
-
-  Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
-  if(pWindow)
-    pDialogQuestion->set_transient_for(*pWindow);
-
-   Bakery::Dialog_OverwriteFile::enumButtons buttonClicked = (Bakery::Dialog_OverwriteFile::enumButtons)pDialogQuestion->run();
-   delete pDialogQuestion;
-   pDialogQuestion = 0;
-
-   return buttonClicked == Dialog_OverwriteFile::BUTTON_Overwrite;
-}
-
-
 } //namespace
